/* Sidebar header (and topbar for mobile) */
.wy-side-nav-search, .wy-nav-top {
  background: #333333;
}

/* Sidebar navigation */
.wy-nav-side {
  background: #4a4a4a;
}

/* Sidebar section headers */
.wy-menu-vertical p.caption {
  color: #72b4ff;
}

.wy-menu-vertical a {
  color: #ffffff;
}

.wy-menu-vertical a:hover {
  background-color: #333333;
}

.wy-nav-content {
    background: #fff;
}

/* format inline code */
.rst-content tt.literal, .rst-content tt.literal, .rst-content code.literal {
    color: #282828;
    background-color: #f8f8f8;
    border: none;
    font-family: SFMono-Regular,Consolas,Liberation Mono,Menlo,monospace;
    font-size: 85%;
}

/* format code blocks */
.rst-content pre.literal-block, .rst-content div[class^='highlight'] {
    border: none;
}

.highlight {
    background: #f8f8f8;
}

.rst-content pre.literal-block, .rst-content div[class^='highlight'] pre, .rst-content .linenodiv pre {
    color: #282828;
    border: none;
    font-family: SFMono-Regular,Consolas,Liberation Mono,Menlo,monospace;
    font-size: 85%;
    line-height: 1.3;
}

/* reduce whitespace  */
.rst-content .section ol li>*, .rst-content .section ul li>* {
    margin-top: 0;
    margin-bottom: 0;
}

.rst-content .section ol li dt>p:last-child {
    margin-bottom: 0;
}

.rst-content div[class^=highlight], .rst-content pre.literal-block {
    margin-top: 0;
    margin-bottom: 12px;
}

.rst-content dl {
    margin-bottom: 0;
}

.rst-content dl.field-list {
    margin-bottom: 12px;
}
.rst-content .section ul, .rst-content .toctree-wrapper ul, .wy-plain-list-disc, article ul {
    margin-bottom: 0;
}
.rst-content .section ol, .rst-content ol.arabic, .wy-plain-list-decimal, article ol {
    margin-bottom: 0;
}

.rst-content dl ol, .rst-content dl table, .rst-content dl ul {
    margin-bottom: 0;
}

.rst-content dl dd {
    margin-bottom: 0;
}
.rst-content .section ol li>p, .rst-content .section ol li>p:last-child, .rst-content .section ul li>p, .rst-content .section ul li>p:last-child {
    margin-bottom: 0;
}

html.writer-html4 .rst-content dl:not(.docutils), html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) {
    margin-bottom: 12px;
}

.rst-content .admonition, .rst-content .admonition-todo, .rst-content .attention, .rst-content .caution, .rst-content .danger, .rst-content .error, .rst-content .hint, .rst-content .important, .rst-content .note, .rst-content .seealso, .rst-content .tip, .rst-content .warning, .wy-alert {
    margin-bottom: 12px;
}

p, .rst-content dl p {
    margin-bottom: 0;
}

p+p, ul+p, ol+p, h1+p, h2+p, h3+p, h4+p, h5+p, h6+p {
    margin-top: 12px;
}

dl dd p:last-child {
    margin-bottom: 0
}

html.writer-html4 .rst-content dl:not(.docutils) dl:not(.field-list)>dt, html.writer-html5 .rst-content dl[class]:not(.option-list):not(.field-list):not(.footnote):not(.glossary):not(.simple) dl:not(.field-list)>dt {
    margin-bottom: 0;
}

h1, h2, h3, h4, h5, h6 {
    margin-block-end: 12px;
}

h2, h3, h4, h5, h6 {
    margin-top: 12px;
}

div.toctree-wrapper {
    margin-top: 12px
}

.rst-content div[class^=highlight] pre {
    padding-left: 6px;
    padding-right: 6px;
    padding-top: 6px;
    padding-bottom: 6px;
}
